@@ -8,9 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.space_analyses_interfaces.distance import Distance
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Distances(Collection):
@@ -175,5 +177,9 @@ class Distances(Collection):
 
         return Distance(self.distances.item(n + 1))
 
+    def __iter__(self) -> Iterator[Distance]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Distances(name="{self.name}")'
